@@ -1,4 +1,4 @@
-__version__ = '0.2.10'
+__version__ = '0.2.11'
 # Copyright (c) 2013. SlickLog.
 __author__ = 'Torindo Nesci'
 
@@ -38,9 +38,9 @@ class ConnectionBuilder:
   def __init__(self, api_key, log_group_name, log_name, endpoint=None):
     if endpoint is None:
       endpoint = ConnectionBuilder.__DEFAULT_ENDPOINT
-    self.api_key = u(api_key).encode('utf8')
-    self.log_group_name = u(log_group_name).encode('utf8')
-    self.log_name = u(log_name).encode('utf8')
+    self.api_key = u(api_key).encode('utf-8')
+    self.log_group_name = u(log_group_name).encode('utf-8')
+    self.log_name = u(log_name).encode('utf-8')
     self.protocol,\
         self.host,\
         self.port,\
@@ -270,7 +270,7 @@ class SlickLogRemoteLogger:
         elapsed = time() - polling_start
     except queue_mod().Empty:
       log('Queue is empty. Wait timeout expired')
-      return None
+    return None
 
   def _acquire_lock(self):
     lock = self.lock
